module.exports = {
  root: true,
  parser: '@typescript-eslint/parser',
  plugins: ['@typescript-eslint', 'react', 'react-hooks', 'babel', 'simple-import-sort', 'jsx-a11y', 'json'],
  parserOptions: {
    ecmaVersion: 2020,
    sourceType: 'module',
  },
  env: {
    browser: true,
    node: true,
    es6: true,
    jest: true,
  },
  extends: [
    'plugin:json/recommended',
    'eslint:recommended',
    'plugin:react/recommended',
    'plugin:prettier/recommended',
    'plugin:@typescript-eslint/recommended',
    'plugin:@typescript-eslint/eslint-recommended',
    'prettier/@typescript-eslint',
    'plugin:jsx-a11y/recommended',
  ],
  globals: {
    importScripts: true,
  },
  rules: {
    'arrow-spacing': 'error',
    'babel/no-invalid-this': 'warn',
    'block-spacing': ['error', 'never'],
    'brace-style': ['error', '1tbs'],
    'comma-spacing': 'error',
    'comma-style': ['error', 'last'],
    curly: ['error', 'all'],
    'eol-last': 'error',
    eqeqeq: ['error', 'always'],
    'func-call-spacing': 'error',
    'guard-for-in': 'off',
    'json/*': ['error', 'allowComments'],
    'jsx-a11y/tabindex-no-positive': 'error',
    'jsx-a11y/alt-text': 'error',
    'jsx-a11y/aria-props': 'error',
    'jsx-a11y/aria-role': 'error',
    'jsx-a11y/img-redundant-alt': 'error',
    'jsx-a11y/accessible-emoji': 'error',
    'keyword-spacing': 'error',
    'linebreak-style': 'off',
    'new-cap': 'off',
    'max-len': [
      'error',
      {
        tabWidth: 2,
        code: 1000,
        comments: 160,
        ignoreComments: false,
        ignoreTrailingComments: false,
      },
    ],
    'no-console': 'error',
    'no-empty-function': [
      'error',
      {
        allow: ['arrowFunctions'],
      },
    ],
    'no-implicit-coercion': 'error',
    'no-invalid-this': 'off',
    'no-lonely-if': 'error',
    'no-multi-spaces': 'error',
    'no-multiple-empty-lines': [
      'error',
      {
        max: 1,
      },
    ],
    'no-unneeded-ternary': 'error',
    'no-useless-computed-key': 'off',
    'no-useless-return': 'error',
    'no-whitespace-before-property': 'error',
    'quote-props': 'off',
    'react/jsx-sort-props': ['error'],
    'react-hooks/rules-of-hooks': 'error',
    'require-jsdoc': 'off',
    'space-before-blocks': 'error',
    'space-before-function-paren': [
      'error',
      {
        anonymous: 'always',
        asyncArrow: 'always',
        named: 'never',
      },
    ],
    'react/prop-types': 0,
    'simple-import-sort/imports': 'error',
    'sort-imports': 'off',
    '@typescript-eslint/explicit-module-boundary-types': 'off',
    '@typescript-eslint/ban-ts-comment': 'off',
    'valid-jsdoc': 'off',
    'react/react-in-jsx-scope': 'off',
    'jsx-a11y/anchor-is-valid': [
      'error',
      {
        components: ['Link'],
        specialLink: ['hrefLeft', 'hrefRight'],
        aspects: ['invalidHref', 'preferButton'],
      },
    ],
  },
  settings: {
    react: {
      pragma: 'React',
      version: 'detect',
      flowVersion: '0.53',
    },
    linkComponents: [
      'Hyperlink',
      {
        name: 'Link',
        linkAttribute: 'to',
      },
    ],
  },
};
